summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmditaskbar.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmditaskbar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
index 7c7891a0..3bf827a3 100644
--- a/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
+++ b/lib/compatibility/kmdi/qextmdi/kmditaskbar.h
@@ -135,7 +135,7 @@ public:
/**
* Constructor (NoFocus, minimum width = 1, an internal TQPtrList of taskbar buttons (autodelete))
*/
- KMdiTaskBar( KMdiMainFrm *tqparent, TQMainWindow::ToolBarDock dock );
+ KMdiTaskBar( KMdiMainFrm *parent, TQMainWindow::ToolBarDock dock );
/**
* Destructor (deletes the taskbar button list)
*/
@@ -198,7 +198,7 @@ protected:
*/
TQPtrList<KMdiTaskBarButton>* m_pButtonList;
/**
* The belonging MDI mainframe (tqparent widget of this)
*/
KMdiMainFrm* m_pFrm;
/**
@@ -198,7 +198,7 @@ protected:
TQPtrList<KMdiTaskBarButton>* m_pButtonList;
/**
- * The belonging MDI mainframe (tqparent widget of this)
+ * The belonging MDI mainframe (parent widget of this)
*/
KMdiMainFrm* m_pFrm;